@@ -47,9 +47,13 @@ void ButtonSelectDlg::loadThemes()
         else  themeConf = DEVICETHEMES + themeDirList.at(i) + "/theme.conf";
 
         QFile file(themeConf);
-        if (!file.open(QIODevice::ReadOnly | QIODevice::Text))
-            QMessageBox::warning(this,"Error with theme config","Couldn't load " + themeDirList.at(i) + " theme config file!",
+        if (!file.open(QIODevice::ReadOnly | QIODevice::Text)) {
+            QMessageBox::warning(this,"Error with theme config","Couldn't load " + themeDirList.at(i) + " theme config file!" +
+                                 " Please download theme again from theme manager.",
                                  QMessageBox::NoButton,QMessageBox::NoButton);
+            themeDirList.removeAt(i);
+            i--;
+        }
 
         else {
             QTextStream in(&file);
