@@ -1,5 +1,3 @@
-#include <QPixmap>
-#include <QPainter>
 #include "buttonwidget.h"
 
 ButtonWidget::ButtonWidget(QWidget *parent, const QString aFilenameUnpressed,const QString aFileNamePressed,
@@ -233,7 +231,7 @@ void ButtonWidget::paintEvent( QPaintEvent* event)
         p.begin(this);
         p.save();
         p.drawPixmap(0, 0, *unpressedPixmap );
-        if(allowText) {
+        if(allowText && !buttonText.contains("blank",Qt::CaseInsensitive)) {
             p.setPen(*textUpColor);
             p.setFont(*textUpFont);
             p.drawText(this->rect(),Qt::AlignCenter,buttonText);
@@ -244,6 +242,34 @@ void ButtonWidget::paintEvent( QPaintEvent* event)
 
 void ButtonWidget::checkButtonCommand()
 {
+        if(fileNameUnPressed.contains("up",Qt::CaseSensitive) && buttonText == "Up" || buttonText == "up")
+        {
+            fileNameUnPressed = "/home/user/.qtirreco/themes/default/buttons/up/unpressed.png";
+            fileNamePressed = "/home/user/.qtirreco/themes/default/buttons/up/pressed.png";
+            confFileName = "/home/user/.qtirreco/themes/default/buttons/up/button.conf";
+            return;
+        }
+        if(fileNameUnPressed.contains("down",Qt::CaseSensitive) && buttonText == "Down" || buttonText == "down")
+        {
+            fileNameUnPressed = "/home/user/.qtirreco/themes/default/buttons/down/unpressed.png";
+            fileNamePressed = "/home/user/.qtirreco/themes/default/buttons/down/pressed.png";
+            confFileName = "/home/user/.qtirreco/themes/default/buttons/down/button.conf";
+            return;
+        }
+        if(fileNameUnPressed.contains("left",Qt::CaseSensitive) && buttonText == "Left" || buttonText == "left")
+        {
+            fileNameUnPressed = "/home/user/.qtirreco/themes/default/buttons/left/unpressed.png";
+            fileNamePressed = "/home/user/.qtirreco/themes/default/buttons/left/pressed.png";
+            confFileName = "/home/user/.qtirreco/themes/default/buttons/left/button.conf";
+            return;
+        }
+        if(fileNameUnPressed.contains("right",Qt::CaseSensitive) && buttonText == "Right" || buttonText == "right")
+        {
+            fileNameUnPressed = "/home/user/.qtirreco/themes/default/buttons/right/unpressed.png";
+            fileNamePressed = "/home/user/.qtirreco/themes/default/buttons/right/pressed.png";
+            confFileName = "/home/user/.qtirreco/themes/default/buttons/right/button.conf";
+            return;
+        }
         if(fileNameUnPressed.contains("next",Qt::CaseInsensitive))
         {
             fileNameUnPressed = "/home/user/.qtirreco/themes/default/buttons/next/unpressed.png";
