@@ -8,6 +8,7 @@ DownloadUserRemoteDlg::DownloadUserRemoteDlg(QWidget *parent) :
     m_ui->setupUi(this);
     m_ui->previousPushButton->setDisabled(true);
     this->setWindowTitle("Download remote");
+    replaceRemote = false;
 
     QUrl url;
     url.setHost("mercury.wipsl.com");
@@ -84,12 +85,28 @@ void DownloadUserRemoteDlg::processReturnValue(int Id,QVariant data)
 
         QFile file("/home/user/MyDocs/qtirreco/Remotes/"+ fileName);
         if (file.exists()) {
-             QMessageBox::warning(this,"Remote name already exists!","Cannot download remote, please delete remote with same name before downloading.",
-                                 QMessageBox::NoButton,QMessageBox::NoButton);
+            replaceRemote = false;
+             /*QMessageBox::warning(this,"Remote name already exists!","Cannot download remote, please delete remote with same name before downloading.",
+                                 QMessageBox::NoButton,QMessageBox::NoButton);*/
+            QDialog *dlg = new QDialog(this);
+            dlg->resize(800,200);
+            dlg->setWindowTitle("Filename already exists!");
+            QLabel *label = new QLabel(dlg);
+            label->setGeometry(100,20,800,50);
+            label->setText("Do you want to replace remote: " + fileName + " ?");
+            label->show();
+            QPushButton *button = new QPushButton(dlg);
+            button->setGeometry(300,75,200,75);
+            button->setText("Replace");
+            button->show();
+            connect(button,SIGNAL(clicked()),this,SLOT(replaceRemoteSlot()));
+            connect(button,SIGNAL(clicked()),dlg,SLOT(deleteLater()));
+            dlg->exec();
         }
-        else {
+
+        if(replaceRemote || !file.exists()) {
             if (!file.open(QIODevice::WriteOnly | QIODevice::Text))
-            return;
+                return;
 
             QTextStream stream( &file );
             stream << data;
@@ -129,6 +146,10 @@ void DownloadUserRemoteDlg::processReturnValue(int Id,QVariant data)
 
     }
 }
+void DownloadUserRemoteDlg::replaceRemoteSlot()
+{
+    replaceRemote = true;
+}
 void DownloadUserRemoteDlg::getRemoteVersionById(QString id)
 {
       if(versionIndex < remoteIdList.count()) {
