@@ -472,13 +472,6 @@ void LayoutWidget::sendIrCommands(QStringList commands)
       //  socket->openSocket(LIRCD);
         const QString command = "SEND_ONCE " +commands.at(0);
         socket->sendSocket(&command);
-      //  if(socket->getPacket(&command) && !socket->getStatus())
-      //          QString error_string("Error: " +*socket->getErrorString());
-       /* QString commandString = commands.at(0);
-        std::string command;
-        command.append("SEND_ONCE " + commandString.toStdString());
-        socket->send(command); */
-
     }
     else {
         timer2->setInterval(1);
@@ -499,15 +492,7 @@ void LayoutWidget::sendIrCommandsSlot2()
 
     if(timer2Index < copyButton->commandChain.count()) {
          const QString command = "SEND_ONCE " +copyButton->commandChain.at(timer2Index);
-            socket->sendSocket(&command);
-         //   if(socket->getPacket(&command) && !socket->getStatus())
-              //      QString error_string("Error: " +*socket->getErrorString());
-
-       /* QString commandString = copyButton->commandChain.at(timer2Index);
-        std::string command;
-        command.append("SEND_ONCE " + commandString.toStdString());
-        socket->send(command);*/
-
+         socket->sendSocket(&command);
          timer2Index++;
          timeout2 = copyButton->timeOut;
          timer2->setInterval(timeout2);
