@@ -121,35 +121,37 @@ void ThemeCreatorDlg::mousePressEvent(QMouseEvent *event)
             delete preview;
         }
     }
+
+    m_ui->editButton->setDisabled(true);
+    m_ui->deleteButton->setDisabled(true);
+
     if(m_ui->tabWidget->currentIndex() == 1) {
-        if(m_ui->scrollAreaWidgetContents->underMouse()) {
+
             for(int j=0;j<buttons->count();j++)
                     buttons->at(j)->setAutoFillBackground(false);
+          //  if(m_ui->scrollAreaWidgetContents->underMouse()) {
 
             for(int i=0;i<buttons->count();i++) {
-                m_ui->editButton->setDisabled(true);
-                m_ui->deleteButton->setDisabled(true);
+                m_ui->editButton->setEnabled(true);
+                m_ui->deleteButton->setEnabled(true);
                 if(buttons->at(i)->underMouse()) {
-                    m_ui->editButton->setEnabled(true);
-                    m_ui->deleteButton->setEnabled(true);
                     currentButtonIndex = i;
                     buttons->at(i)->setAutoFillBackground(true);
                     QPalette palette;
                     palette.setBrush(QPalette::Window,QColor(Qt::cyan));
                     buttons->at(i)->setPalette(palette);
+                    break;
                 }
-            }
+          //  }
         }
     }
     if(m_ui->tabWidget->currentIndex() == 2) {
 
-        if(m_ui->scrollAreaWidgetContents_2->underMouse()) {
             for(int j=0;j<backgrounds->count();j++)
                     backgrounds->at(j)->setAutoFillBackground(false);
+          //  if(m_ui->scrollAreaWidgetContents_2->underMouse()) {
 
             for(int i=0;i<backgrounds->count();i++) {
-                m_ui->editButton->setDisabled(true);
-                m_ui->deleteButton->setDisabled(true);
                 if(backgrounds->at(i)->underMouse()) {
                     m_ui->editButton->setEnabled(true);
                     m_ui->deleteButton->setEnabled(true);
@@ -158,8 +160,9 @@ void ThemeCreatorDlg::mousePressEvent(QMouseEvent *event)
                     QPalette palette;
                     palette.setBrush(QPalette::Window,QColor(Qt::cyan));
                     backgrounds->at(i)->setPalette(palette);
+                    break;
                 }
-            }
+         //   }
          }
     }
 }
