@@ -583,8 +583,11 @@ void ThemeManager::on_downloadPushButton_clicked()
             QFile file("/home/user/MyDocs/qtirreco/themes/"+themeName+"/theme.conf");
             if (!file.open(QIODevice::ReadOnly | QIODevice::Text))
             {
-                QMessageBox::warning(this,"Error","Couldn't load theme info!",
-                QMessageBox::NoButton,QMessageBox::NoButton);
+                QMessageBox::warning(this,"Error with theme config","Couldn't load " + themeName + " theme config file!" +
+                             " Theme will be deleted, please download theme again from theme manager.",
+                             QMessageBox::NoButton,QMessageBox::NoButton);
+                this->deleteTheme(themeName);
+                this->clearAllData();
                 return;
             }
             QTextStream in(&file);
@@ -750,21 +753,28 @@ void ThemeManager::loadThemes()
 
         QString themeConf = "/home/user/MyDocs/qtirreco/themes/" + strList.at(i) + "/theme.conf";
         QFile file(themeConf);
-        if (!file.open(QIODevice::ReadOnly | QIODevice::Text))
-        return;
+        if (!file.open(QIODevice::ReadOnly | QIODevice::Text)) {
+                 QMessageBox::warning(this,"Error with theme config","Couldn't load " + strList.at(i) + " theme config file!" +
+                                 " Theme will be deleted, please download theme again from theme manager.",
+                                 QMessageBox::NoButton,QMessageBox::NoButton);
+                this->deleteTheme(themeDirList.at(i));
+                this->clearAllData();
+                return;
+            }
+        else {
+            QTextStream in(&file);
+            while (!in.atEnd())
+            {
+                QString line = in.readLine();
+                process_line(line);
+            }
 
-        QTextStream in(&file);
-        while (!in.atEnd())
-        {
-            QString line = in.readLine();
-            process_line(line);
+            item->setText(themeName);
+
+            m_ui->listWidget->insertItem(i, item);
+            m_ui->listWidget->show();
+            file.close();
         }
-
-        item->setText(themeName);
-
-        m_ui->listWidget->insertItem(i, item);
-        m_ui->listWidget->show();
-        file.close();
     }
 }
 void ThemeManager::process_line(QString line)
@@ -877,25 +887,6 @@ void ThemeManager::on_deletePushButton_clicked()
         }
     }
 
-  /*  if(!remoteFiles.isEmpty()) {
-        for(int i=0;i<remoteFiles.count();i++) {
-            QFile remoteFile("/home/user/MyDocs/qtirreco/Remotes/"+remoteFiles.at(i));
-
-            if (!remoteFile.open(QIODevice::ReadOnly | QIODevice::Text))
-                return;
-
-            QTextStream in(&remoteFile);
-            while (!in.atEnd())
-            {
-                QString line = in.readLine();
-                readUsedThemes(line);
-            }
-            if(usedThemesByRemote.contains(themeToDelete,Qt::CaseInsensitive))
-                remoteNamesUsingThemeToBeDeleted.append(remoteFiles.at(i));
-            usedThemesByRemote.clear();
-            remoteFile.close();
-       }
-    }*/
 
     if(usedThemes.contains(themeToDelete,Qt::CaseInsensitive)) {
 
@@ -951,6 +942,45 @@ void ThemeManager::readUsedThemes(QString line)
         }
     }
 }
+void ThemeManager::deleteTheme(QString delThemeName)
+{
+    QDir dir;
+    QString homePath = dir.currentPath();
+    dir.setPath("/home/user/MyDocs/qtirreco/themes/" + delThemeName + "/buttons/");
+    QStringList buttonDirs = dir.entryList(QDir::NoDotAndDotDot | QDir::Dirs, QDir::Name);
+    for(int i=0;i<buttonDirs.count();i++)
+    {
+        dir.setPath("/home/user/MyDocs/qtirreco/themes/" + delThemeName + "/buttons/" + buttonDirs.at(i));
+        QStringList buttonFiles = dir.entryList(QDir::Files);
+        for(int j=0;j<buttonFiles.count();j++)
+        {
+            QFile file("/home/user/MyDocs/qtirreco/themes/" + delThemeName + "/buttons/" + buttonDirs.at(i) + "/" + buttonFiles.at(j));
+            file.remove();
+        }
+    }
+    dir.setPath("/home/user/MyDocs/qtirreco/themes/" + delThemeName + "/bg/");
+    QStringList bgDirs = dir.entryList(QDir::NoDotAndDotDot | QDir::Dirs, QDir::Name);
+    for(int i=0;i<bgDirs.count();i++)
+    {
+        dir.setPath("/home/user/MyDocs/qtirreco/themes/" + delThemeName + "/bg/" + bgDirs.at(i));
+        QStringList bgFiles = dir.entryList(QDir::Files);
+        for(int j=0;j<bgFiles.count();j++)
+        {
+            QFile file("/home/user/MyDocs/qtirreco/themes/" + delThemeName + "/bg/" + bgDirs.at(i) + "/" + bgFiles.at(j));
+            file.remove();
+        }
+    }
+    dir.setPath("/home/user/MyDocs/qtirreco/themes/" + delThemeName + "/");
+    QStringList extraFiles = dir.entryList(QDir::Files);
+    for(int i=0;i<extraFiles.count();i++)
+    {
+        QFile file("/home/user/MyDocs/qtirreco/themes/" + delThemeName + "/" + extraFiles.at(i));
+        file.remove();
+    }
+    dir.setPath(homePath);
+    QString delCommand("rm -rf /home/user/MyDocs/qtirreco/themes/" + delThemeName);
+    system(delCommand.toAscii().data());
+}
 void ThemeManager::deleteTheme()
 {
     QDir dir;
